<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:regExp="http://exslt.org/regular-expressions"
				extension-element-prefixes="regExp">
	
	<!-- Identity transformation -->
	<xsl:template match="/ | @* | * | comment() | processing-instruction() | text()">
		<xsl:copy>
			<xsl:apply-templates select="@* | * | comment() | processing-instruction() | text()" />
		</xsl:copy>
	</xsl:template>
	
	<!-- Template to replace a string by another -->
	<xsl:template name="string-replace-all">
		<xsl:param name="text" />
		<xsl:param name="replace" />
		<xsl:param name="by" />
		<xsl:choose>
			<xsl:when test="contains($text, $replace)">
				<xsl:value-of select="substring-before($text,$replace)" />
				<xsl:value-of select="$by" />
				<xsl:call-template name="string-replace-all">
					<xsl:with-param name="text" select="substring-after($text,$replace)" />
					<xsl:with-param name="replace" select="$replace" />
					<xsl:with-param name="by" select="$by" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$text" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>	
   
	<!-- configure output  --> 	
	<xsl:output method="xml" encoding="UTF-8"/>
	
    <!-- Treat the Config part -->
    <xsl:template match="/Config">
   
		<!-- Re-copy the Config node -->   
		<xsl:element name = "{name(.)}">
		
			<!-- change version attribute value from 2.0 to 2.1 -->  
			<xsl:attribute name = "version">2.1</xsl:attribute>
						
			<xsl:apply-templates select="*" />
			
		</xsl:element>
	</xsl:template>
	
	<xsl:template match="/Config/RSServers">
		<xsl:copy>
			<!-- keep the attributes -->
			<xsl:copy-of select="@*"/>
			
			<xsl:for-each select="RSServer">
				
				<xsl:choose>
			
					<!-- use cloud.tixeo.com instead of meet.workspace3d.com -->
					<xsl:when test="contains(Address, 'meet.workspace3d.com')">
						<xsl:copy>
							<xsl:copy-of select="@*"/>
							<xsl:element name = "Address">
								<xsl:value-of select="'https://cloud.tixeo.com/meet/'"/>
							</xsl:element>
							<xsl:copy-of select="Login | Password"/>
						</xsl:copy>
					</xsl:when>
					
					<!-- rename webapp /workspace3d/ to /meet/ -->
					<xsl:when test="contains(Address, '/workspace3d/')">
						<xsl:copy>
							<xsl:copy-of select="@*"/>
							<xsl:element name = "Address">
								<xsl:call-template name="string-replace-all">
									<xsl:with-param name="text">
										<xsl:value-of select="Address"/>
									</xsl:with-param>
									<xsl:with-param name="replace" select="'/workspace3d/'" />
									<xsl:with-param name="by" select="'/meet/'" />
								</xsl:call-template>
							</xsl:element>
							<xsl:copy-of select="Login | Password"/>
						</xsl:copy>
					</xsl:when>
					
					<!-- else just copy values -->
					<xsl:otherwise>
						<xsl:copy>
							<xsl:copy-of select="@*"/>
							<xsl:copy-of select="*"/>
						</xsl:copy>
					</xsl:otherwise>
					
				</xsl:choose>

			</xsl:for-each>
		</xsl:copy>
	</xsl:template>

</xsl:stylesheet>